import type { APIRoute } from 'astro';
import { db } from '@db/database.ts';
import { API_SECRET } from 'astro:env/server';

export const GET: APIRoute = async ({ request }) => {
  if (API_SECRET && request.headers.get('authorization') !== `Basic ${API_SECRET}`) {
    return new Response(null, { status: 401 });
  }

  const teams = await db.getTeams({});

  const response = [];
  for (const team of teams) {
    const users = [];
    if (team.memberOne.uuid) users.push(team.memberOne.uuid);
    if (team.memberTwo.uuid) users.push(team.memberTwo.uuid);

    response.push({
      name: team.name,
      color: team.color,
      users: users
    });
  }

  return new Response(JSON.stringify(response));
};
